<?php
/*
 * Plugin Name: QSM - Advanced Leaderboard
 * Description: Enhance the leaderboard system
 * Version: 1.0.13
 * Text Domain:qsm-advanced-leaderboard
 * Author: QSM Team
 * Author URI: https://quizandsurveymaster.com/
 * Plugin URI: https://quizandsurveymaster.com/
 */
$version = '1.0.13';

//QSM Adv. Leaderboard check license
if (!class_exists('EDD_SL_Plugin_Updater')) {

	// load our custom updater
	include( 'php/EDD_SL_Plugin_Updater.php' );

	// retrieve our license key from the DB
	$advanced_leaderboard_data = get_option('qsm_addon_advanced_leaderboard_settings', '');
	if (isset($advanced_leaderboard_data["license_key"])) {
		$license_key = trim($advanced_leaderboard_data["license_key"]);
	} else {
		$license_key = '';
	}

	// setup the updater
	$edd_updater = new EDD_SL_Plugin_Updater('https://quizandsurveymaster.com', __FILE__, array(
		'version' => $version, // current version number
		'license' => $license_key, // license key (used get_option above to retrieve from DB)
		'item_name' => 'Advanced Leaderboard', // name of this plugin
		'author' => 'QSM Team'  // author of this plugin
		)
	);
}

include_once("php/addon-settings-tab-content.php");
include_once("php/quiz-settings-tab-content.php");
include_once("php/integration.php");
include_once("includes/mlw_al_shortcode.php");
include_once("includes/mlw_al_widgets.php");
include_once("includes/mlw_al_generate_settings.php");

add_action('admin_init', 'qsm_addon_advanced_leaderboard_register_quiz_settings_tabs');
add_action('admin_init', 'qsm_addon_advanced_leaderboard_register_addon_settings_tabs');
add_shortcode('mlw_qmn_all_leaderboard', 'mlw_qmn_al_all_leaderboard_shortcode');
add_shortcode('mlw_qmn_single_leaderboard', 'mlw_qmn_al_leaderboard_shortcode');
add_shortcode('mlw_qmn_all_graph', 'mlw_qmn_al_all_graph_shortcode');
add_shortcode('mlw_qmn_single_graph', 'mlw_qmn_al_single_graph_shortcode');
add_action('widgets_init', 'mlw_qmn_register_widget');
add_action('admin_menu', 'mlw_qmn_al_add_menu', 11);
add_action('admin_init', 'mlw_qmn_al_register_settings');
add_action('wp_enqueue_scripts', 'mlw_qsm_leaderboard_custom_css');
add_action('admin_notices', 'mlw_qsm_leaderboard_admin_notices');

add_action('admin_init', 'qsm_addon_qsm_advanced_leaderboard_textdomain');

register_activation_hook(__FILE__, 'mlw_qmn_al_activate');

function mlw_qmn_register_widget() {
	register_widget("Mlw_Qmn_Al_Widget");
	register_widget("Mlw_Qmn_Al_Graph_Widget");
}

function mlw_qmn_al_register_settings() {
	register_setting('mlw_qmn_al_settings', 'mlw_qmn_al_option');
	 load_plugin_textdomain( 'qsm-advanced-leaderboard', false, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
}

function mlw_qmn_al_add_menu() {
	if ( function_exists('add_submenu_page') ) {
		global $mlwQuizMasterNext;
		if( version_compare( $mlwQuizMasterNext->version, '7.0.0', '<' ) ) {
			add_submenu_page( QSM_SUBMENU, 'Advanced Leaderboard', 'Advanced Leaderboard', 'moderate_comments', 'mlw_qmn_al', 'mlw_qmn_generate_leaderboard_settings');
		} else {
			add_submenu_page('qsm_dashboard', 'Advanced Leaderboard', 'Advanced Leaderboard', 'moderate_comments', 'mlw_qmn_al', 'mlw_qmn_generate_leaderboard_settings');
		}
	}
}

function mlw_qmn_al_activate() {
	if (!get_option('mlw_qmn_al_option')) {
		$mlw_al_option = array();
		$mlw_al_option["variables"] = array('rank' => 'yes', 'user_name' => 'yes', 'correct_score' => 'yes');
		$mlw_al_option["template"] = "%USER_NAME% - %CORRECT_SCORE%%";
		$mlw_al_option["graph_color"] = "#00AEEF";
		$mlw_al_option["graph_font"] = "#FFF";
		add_option('mlw_qmn_al_option', $mlw_al_option);
	}
	flush_rewrite_rules();
}

function mlw_qsm_leaderboard_custom_css() {
	$mlw_qmn_al_options = get_option('mlw_qmn_al_option');
	$graph_color = (isset($mlw_qmn_al_options['graph_color']) ? $mlw_qmn_al_options['graph_color'] : '#00AEEF');
	$graph_font = (isset($mlw_qmn_al_options['graph_font']) ? $mlw_qmn_al_options['graph_font'] : '#FFF');
	echo '<style type="text/css">
	table.quiz_leaderboard_wrapper{width: 100%;border-collapse: collapse;border-spacing: 0;border: 0;color: #212529;}
	table.quiz_leaderboard_wrapper tr{}
	table.quiz_leaderboard_wrapper tr:nth-child(even) th, table.quiz_leaderboard_wrapper tr:nth-child(even) td{background: #dee2e6;}
	table.quiz_leaderboard_wrapper th, table.quiz_leaderboard_wrapper td{font-size: 14px;font-weight: normal;line-height: 20px;text-align: center;padding: .5rem;border: 1px solid #ccc;}
	table.quiz_leaderboard_wrapper th{font-size: 14px;font-weight: bold;line-height: 20px;background: #454d55;color: #FFF;}
	ol.quiz_leaderboard_wrapper{display: inline-block;background: #454d55;max-width: 100%;box-sizing: border-box;color: #FFF;font-size: 16px;border-radius: 6px;list-style-position: inside;padding: 15px 20px;margin: 0;}
	ol.quiz_leaderboard_wrapper li{padding: 2px 0;}
	.quiz_graph_wrapper ul.mlw_shortcode_bargraph{list-style: none;padding: 10px 0;margin: 0;width: 560px;}
	.quiz_graph_wrapper ul.mlw_shortcode_bargraph li{background: '.$graph_color.';color: '.$graph_font.';border-radius: 2px;font-style: italic;font-weight: bolder;font-size: 14px;line-height: 20px;padding: 5px 10px;margin-bottom: 5px;}
	</style>';
}

function mlw_qsm_leaderboard_admin_notices(){
	$notice_status = get_option('advanced_leaderboard_compatibility');
	if(!$notice_status){
		echo '<div class="updated is-dismissible">
			<p>Advanced Leaderboard Compatible with <a href="https://wordpress.org/plugins/quiz-master-next/" target="__blank" rel="noopener">QSM 7.1.14</a></p>
		</div>';
		update_option('advanced_leaderboard_compatibility', '7.1.14');
	}
	
}

/**
     * Adds localization support for Advanced timer addon
     */
      function qsm_addon_qsm_advanced_leaderboard_textdomain() {
        load_plugin_textdomain( 'qsm-advanced-leaderboard', false, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
    }