<?php
if (!defined('ABSPATH')) {
	exit;
}

function mlw_qmn_al_add_rewrite_rule() {
	$cpt_slug = 'quiz';
	$settings = (array) get_option('qmn-settings');
	if (isset($settings['cpt_slug'])) {
		$cpt_slug = trim(strtolower(str_replace(' ', '-', $settings['cpt_slug'])));
	}
	add_rewrite_rule("^{$cpt_slug}/([^/]+)/leaderboard/?$", 'index.php?post_type=qsm_quiz&name=$matches[1]&leaderboard=1', 'top');
}

add_action('init', 'mlw_qmn_al_add_rewrite_rule');

function mlw_qmn_al_register_query_var($vars) {
	$vars[] = 'leaderboard';
	return $vars;
}

add_filter('query_vars', 'mlw_qmn_al_register_query_var');

function prefix_url_rewrite_templates() {
	if (get_query_var('leaderboard') && is_singular('qsm_quiz')) {
		global $wpdb;
		$quizObj = get_queried_object();
		$quiz_id = get_post_meta($quizObj->ID, 'quiz_id', true);
		global $mlwQuizMasterNext;
		$success = $mlwQuizMasterNext->pluginHelper->prepare_quiz($quiz_id);
		$al_data = $mlwQuizMasterNext->pluginHelper->get_quiz_setting("adv_leaderboard");
		if (isset($al_data['enable_result_link']) && '1' == $al_data['enable_result_link']) {
			add_filter('template_include', function() {
				return dirname(__FILE__) . '/../templates/leaderboard.php';
			});
		}
	}
}

add_action('template_redirect', 'prefix_url_rewrite_templates');

function get_quiz_al_leaderboard_link($quiz_id = 0) {
	$leaderboard_link = home_url();
	if ($quiz_id) {
		$structure = get_option('permalink_structure');
		$leaderboard_link = qsm_get_post_id_from_quiz_id($quiz_id);
		if (!empty($structure)) {
			$leaderboard_link = trailingslashit($leaderboard_link) . 'leaderboard/';
		} else {
			$leaderboard_link = add_query_arg('leaderboard', '1', $leaderboard_link);
		}
	}
	return $leaderboard_link;
}
function get_leaderboard_position_by_result_id($quiz_id = 0, $result_id = 0) {
	global $wpdb, $mlwQuizMasterNext;
	$positionInfo = false;
	if ($quiz_id && $result_id) {
		$prepare_quiz = $mlwQuizMasterNext->pluginHelper->prepare_quiz($quiz_id);
		$al_data = $mlwQuizMasterNext->pluginHelper->get_quiz_setting("adv_leaderboard");
		$mlw_result_data = $wpdb->get_results("SELECT `result_id`, `correct_score`, `point_score`, `quiz_results` FROM `{$wpdb->prefix}mlw_results` WHERE `quiz_id`='{$quiz_id}' AND `deleted`='0'");
		if (!empty($mlw_result_data)) {
			$total_results = count($mlw_result_data);
			if (isset($al_data['show_position_limit']) && $total_results < intval($al_data['show_position_limit'])) {
				return false;
			}
			foreach ($mlw_result_data as $key => $mlw_eaches) {
				$time_taken = 0;
				$mlw_qmn_results_array = @unserialize($mlw_eaches->quiz_results);
				if (is_array($mlw_qmn_results_array)) {
					$time_taken = $mlw_qmn_results_array[0];
					if (isset($mlw_qmn_results_array['timer_ms']) && $mlw_qmn_results_array['timer_ms'] > 0) {
						$time_taken = $mlw_qmn_results_array['timer_ms'];
					} else {
						$time_taken = ($time_taken * 1000);
					}
				}
				$mlw_result_data[$key]->total_time_taken = $time_taken;
			}
			array_multisort(array_column($mlw_result_data, 'correct_score'), SORT_DESC, array_column($mlw_result_data, 'total_time_taken'), SORT_ASC, $mlw_result_data);
			/**
			 * Find Position
			 */
			$mlw_rank = 0;
			$rank = 1;
			foreach ($mlw_result_data as $mlw_eaches) {
				if ($mlw_eaches->result_id == $result_id) {
					$mlw_rank = $rank;
					break;
				}
				$rank++;
			}
			$positionInfo = array('position' => $mlw_rank, 'total_results' => $total_results);
		}
	}
	return $positionInfo;
}

function find_leaderboard_position_func() {
	global $wpdb;
	$response = '';
	if (isset($_POST['email']) && !empty($_POST['email'])) {
		$quiz_id = $_POST['quiz_id'];
		$email = $_POST['email'];
		$usr_result = $wpdb->get_row($wpdb->prepare("SELECT `result_id`, `quiz_id` FROM `{$wpdb->prefix}mlw_results` WHERE `email`=LOWER(%s) AND `quiz_id`=%s ORDER BY `result_id` DESC", strtolower($email), $quiz_id), ARRAY_A);
		if (!empty($usr_result)) {
			$positionInfo = get_leaderboard_position_by_result_id($usr_result['quiz_id'], $usr_result['result_id']);
			if ($positionInfo && $positionInfo['position'] > 0) {
				$mlw_rank = $positionInfo['position'];
				$total_results = $positionInfo['total_results'];
				$response .= '<div class="col-12">';
				$response .= '<h5 class="card-title mb-4">' . __( 'Your Position is', 'qsm-advanced-leaderboard') . ': </h5>';
				$response .= $mlw_rank . ' out of ' . $total_results;
				$response .= '<br/><br/>';
				$response .= '<button type="button" class="reload-form btn btn-primary btn-sm">' . __( 'Go Back', 'qsm-advanced-leaderboard') . '</button>';
				$response .= '</div>';
			} else {
				$response .= '<h5 class="card-title mb-4">';
				$response .= __( 'No position info available right now. Please try again later.', 'qsm-advanced-leaderboard' );
				$response .= '<br/><br/>';
				$response .= '<button type="button" class="reload-form btn btn-primary btn-sm">' . __( 'Go Back', 'qsm-advanced-leaderboard' ) . '</button>';
				$response .= '</h5>';
			}
		} else {
			$response .= '<h5 class="card-title mb-4">';
			$response .= __( 'No result found with your email address.', 'qsm-advanced-leaderboard' );
			$response .= '<br/><br/>';
			$response .= '<button type="button" class="reload-form btn btn-primary btn-sm">' . __( 'Go Back', 'qsm-advanced-leaderboard' ) . '</button>';
			$response .= '</h5>';
		}
	}
	echo $response;
	exit;
}

add_action("wp_ajax_find_leaderboard_position", "find_leaderboard_position_func");
add_action("wp_ajax_nopriv_find_leaderboard_position", "find_leaderboard_position_func");

function mlw_qmn_al_template_variables($content, $mlw_quiz_array) {
	global $wpdb, $mlwQuizMasterNext;
	$quiz_id = is_object($mlw_quiz_array) ? $mlw_quiz_array->quiz_id : $mlw_quiz_array['quiz_id'];
	$user_email = is_object($mlw_quiz_array) ? $mlw_quiz_array->user_email : $mlw_quiz_array['user_email'];
	$result_id = is_object($mlw_quiz_array) ? $mlw_quiz_array->result_id : (isset($mlw_quiz_array['result_id']) ? $mlw_quiz_array['result_id'] : 0);
	if (false !== strpos($content, '%LEADERBOARD_POSITION%')) {
		$position = '';
		if (!empty($result_id) && $result_id >  0) {
			$positionInfo = get_leaderboard_position_by_result_id($quiz_id, $result_id);
			if ($positionInfo && $positionInfo['position'] > 0) {
				$position = $positionInfo['position'] . ' out of ' . $positionInfo['total_results'];
			}
		}
		$content = str_replace("%LEADERBOARD_POSITION%", $position, $content);
	}
	if (false !== strpos($content, '%LEADERBOARD_POSITION_URL%')) {
		$leaderboard_link = get_quiz_al_leaderboard_link($quiz_id);
		$content = str_replace("%LEADERBOARD_POSITION_URL%", $leaderboard_link, $content);
	}
	return $content;
}

add_filter('mlw_qmn_template_variable_results_page', 'mlw_qmn_al_template_variables', 99, 2);

function mlw_qmn_al_text_variable_list($variable_list) {
	global $mlwQuizMasterNext;
	$template_array =  array (
		'%LEADERBOARD_POSITION%'=> __('Display User Position out of total results (ie. 15 out of 52)', 'qsm-advanced-leaderboard' ),
		'%LEADERBOARD_POSITION_URL%'=> __('Display Leaderboard URL to check position.', 'qsm-advanced-leaderboard'  )
	);

	if( version_compare( $mlwQuizMasterNext->version, '7.3.4', '>' ) ){
		$leaderboard= array(
			'Advanced Leaderboard' => $template_array       
		);
	} else {
		$extra_variables = $template_array;
	}
	$variable_list = array_merge($variable_list, $leaderboard );
	return $variable_list;
}

add_filter('qsm_text_variable_list', 'mlw_qmn_al_text_variable_list', 10);

function mlw_qmn_get_rank($data = '', $dense_value, $order)
{

	$data = json_decode(json_encode($data) , true);
	$array_for_require_score = array();
	$dense_rank = array();

	if ($order == 'score_asc' || $order == 'score')
	{
		$key = 'correct_score';
	}
	if ($order == 'point_score_asc' || $order == 'point_score')
	{
		$key = 'point_score';
	}

	$score_for_dense = 0;
	$require_time = 0;
	$times = array();

	foreach ($data as $val)
	{
		$a = array();
		$quiz_results = @unserialize($val['quiz_results']);
		$time = ($quiz_results['timer_ms'] / 1000);

		if (!in_array($val[$key], $dense_rank) && $val[$key] == $dense_value)
		{
			$times = qsm_get_time_values($data, $val[$key] , $key);

			array_push($dense_rank, $val[$key]);

			$a = array(
				"required_score" => $val[$key],
				"time_value" => $times
			);
			return $a;
		}
	}
	return $array_for_require_score;
}
function qsm_get_time_values($data, $dense_rank , $key)
{
	$times = array();

	foreach ($data as $val)
	{
		if ($val[$key] == $dense_rank)
		{
			$quiz_results = @unserialize($val['quiz_results']);
			$time = $quiz_results['timer_ms'] / 1000;
			array_push($times, $time);
		}
	}
	return min($times);
}
