<?php
if (!defined('ABSPATH')) {
	exit;
}

/**
 * Registers your tab in the quiz settings page
 *
 * @since 1.2.0
 * @return void
 */
function qsm_addon_advanced_leaderboard_register_quiz_settings_tabs() {
	global $mlwQuizMasterNext;
	if (!is_null($mlwQuizMasterNext) && !is_null($mlwQuizMasterNext->pluginHelper) && method_exists($mlwQuizMasterNext->pluginHelper, 'register_quiz_settings_tabs')) {
		$mlwQuizMasterNext->pluginHelper->register_quiz_settings_tabs("Advanced Leaderboard", 'qsm_addon_advanced_leaderboard_quiz_settings_tabs_content');
	}
}

/**
 * Generates the content for your quiz settings tab
 *
 * @since 1.2.0
 * @return void
 */
function qsm_addon_advanced_leaderboard_quiz_settings_tabs_content() {

	global $mlwQuizMasterNext;

	//If nonce is set and correct, save the form
	if (isset($_POST["advanced_leaderboard_quiz_integration_nonce"]) && wp_verify_nonce($_POST['advanced_leaderboard_quiz_integration_nonce'], 'advanced_leaderboard_quiz_integration')) {
		$qsm_al_data = array(
			'enable_result_link' => sanitize_text_field($_POST["enable_result_link"]),
			'show_position_limit' => sanitize_text_field($_POST["show_position_limit"]),
		);
		$mlwQuizMasterNext->pluginHelper->update_quiz_setting("adv_leaderboard", $qsm_al_data);
		$mlwQuizMasterNext->alertManager->newAlert(__( 'Your settings has been saved successfully!', 'qsm-advanced-leaderboard' ), 'success');
	}

	// Load the settings
	$al_data = $mlwQuizMasterNext->pluginHelper->get_quiz_setting("adv_leaderboard");
	$al_data_defaults = array(
		'enable_result_link' => 0,
		'show_position_limit' => 0,
	);
	$qsm_al_data = wp_parse_args($al_data, $al_data_defaults);
	?>
	<div id="tabs-gsc-integration" class="mlw_tab_content">
		<h2><?php _e( 'Advanced Leaderboard', 'qsm-advanced-leaderboard' ); ?></h2>
		<form action="" method="post">
			<button class="button-primary"><?php _e( 'Save Settings', 'qsm-advanced-leaderboard' ); ?></button>
			<table class="form-table" style="width: 100%;">
				<tr valign="top">
					<th scope="row">
						<label><?php _e( 'Enable Unique Quiz Result Link?', 'qsm-advanced-leaderboard' ); ?></label>
					</th>
					<td>
						<fieldset class="buttonset buttonset-hide " data-hide='1'>
							<input type="radio" id="enable_result_link-1" name="enable_result_link" value="1" <?php echo ($qsm_al_data["enable_result_link"] == 1) ? 'checked="checked"' : ''; ?>/>
							<label for="enable_result_link-1"><?php _e( 'Yes', 'qsm-advanced-leaderboard' ); ?> </label>
							<input type="radio" id="enable_result_link-0" name="enable_result_link" value="0" <?php echo ($qsm_al_data["enable_result_link"] == 0) ? 'checked="checked"' : ''; ?>/>
							<label for="enable_result_link-0"><?php _e( 'No', 'qsm-advanced-leaderboard' ); ?> </label>
						</fieldset>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">
						<label><?php _e( 'When should the user be able to accessing the Result Position? (Leave 0 if the user can access anytime)', 'qsm-advanced-leaderboard' ); ?></label>
					</th>
					<td>
						<input type="number" step="1" min="0" id="show_position_limit" name="show_position_limit" value="<?php echo $qsm_al_data['show_position_limit'];?>" />
					</td>
				</tr>
			</table>
			<?php wp_nonce_field('advanced_leaderboard_quiz_integration', 'advanced_leaderboard_quiz_integration_nonce'); ?>
			<button class="button-primary"><?php _e( 'Save Settings', 'qsm-advanced-leaderboard' ); ?></button>
		</form>
	</div>
	<?php
}
